pub enum ActivityPrivacy {
Public,
FollowersOnly,
MutualsOnly,
Private,
}Variants
Public
All users can see this activity.
FollowersOnly
Only users who follow this user or those within the same instance who have the ViewPrivateActivity permission can see this activity.
MutualsOnly
Only users who both follow and are followed by this user, or those within the same instance who have the ViewPrivateActivity permission, can see this activity.
Private
No one except users within the same instance who have the ViewPrivateActivity permission can see this activity.